@@ -5,9 +5,9 @@ from ploomber.dag.DAGConfigurator import DAGConfigurator
 from ploomber.env.env import Env
 from ploomber.env.decorators import load_env, with_env
 from ploomber.placeholders.SourceLoader import SourceLoader
-from ploomber.jupyter import _load_jupyter_server_extension
+from ploomber.jupyter.manager import _load_jupyter_server_extension
 
-__version__ = '0.8.5'
+__version__ = '0.8.6'
 
 # Set default logging handler to avoid "No handler found" warnings.
 
