@@ -106,7 +106,7 @@ class CustomParser(argparse.ArgumentParser):
     def process_factory_dotted_path(self, dotted_path):
         """Parse a factory entry point, returns initialized dag and parsed args
         """
-        entry = load_dotted_path(dotted_path, raise_=True)
+        entry = load_dotted_path(str(dotted_path), raise_=True)
 
         # add args using the function's signature
         required, _ = _add_args_from_callable(self, entry)
@@ -137,6 +137,136 @@ class CustomParser(argparse.ArgumentParser):
         return dag, args
 
 
+class EntryPoint:
+    """
+    Handles common operations on the 4 types of entry points. Exposes a
+    pathlib.Path-like interface
+    """
+    Directory = 'directory'
+    Pattern = 'pattern'
+    File = 'file'
+    DottedPath = 'dotted-path'
+
+    def __init__(self, value):
+        self.value = value
+        self.type = find_entry_point_type(value)
+
+    def exists(self):
+        if self.type == self.Pattern:
+            return True
+        elif self.type in {self.Directory, self.File}:
+            return Path(self.value).exists()
+        elif self.type == self.DottedPath:
+            return load_dotted_path(self.value, raise_=False) is not None
+
+    def is_dir(self):
+        return self.type == self.Directory
+
+    @property
+    def suffix(self):
+        return None if self.type != self.File else Path(self.value).suffix
+
+    def __repr__(self):
+        return repr(self.value)
+
+    def __str__(self):
+        return str(self.value)
+
+    def load(self, parser, argv):
+        """Load DAG from entry point
+
+        Parameters
+        ----------
+        parser : CustomParser
+            The cli parser object
+
+        argv : list
+            Command line arguments
+        """
+        help_cmd = '--help' in argv or '-h' in argv
+
+        # if the file does not exist but the value has sufix yaml/yml, show a
+        # warning because the last thing to try is to interpret it as a dotted
+        # path and that's probably not what the user wants
+        if not self.exists() and self.suffix in {'.yaml', '.yml'}:
+            warnings.warn('Entry point value "{}" has extension "{}", which '
+                          'suggests a spec file, but the file doesn\'t '
+                          'exist'.format(self, self.suffix))
+
+        # even if the entry file is not a file nor a valid module, show the
+        # help menu, but show a warning
+        if (help_cmd and not self.exists()):
+            warnings.warn('Failed to load entry point "{}". It is not a file '
+                          'nor a valid dotted path'.format(self))
+
+            args = parser.parse_args()
+        elif self.type == EntryPoint.DottedPath:
+            # if pipeline.yaml, .type will return dotted path, because that's
+            # a valid dotted-path value but this can trip users over so we
+            # raise a exception here for users to check for name typos
+            if str(self.value) in {'pipeline.yaml', 'pipeline.yml'}:
+                raise ValueError('Error loading entry point. When passing '
+                                 f'{self!r}, a YAML file is expected, but '
+                                 'such file does not exist')
+
+            dag, args = parser.process_factory_dotted_path(self)
+        else:
+            dag, args = _process_file_dir_or_glob(parser)
+
+        return dag, args
+
+
+# TODO: the next two functions are only used to override default behavior
+# when using the jupyter extension, but they have to be integrated with the CLI
+# to provide consistent behavior. The problem is that logic implemented
+# in _process_file_dir_or_glob and _process_factory_dotted_path
+# also contains some CLI specific parts that we don't require here
+def find_entry_point_type(entry_point):
+    """
+
+    Step 1: If not ENTRY_POINT is defined nor a value is passed, a default
+    value is used (pipeline.yaml for CLI, recursive lookup for Jupyter client).
+    If ENTRY_POINT is defined, this simply overrides the default value, but
+    passing a value overrides the default value. Once the value is determined.
+
+    Step 2: If value is a valid directory, DAG is loaded from such directory,
+    if it's a file, it's loaded from that file (spec), finally, it's
+    interpreted as a dotted path
+    """
+    if '*' in entry_point:
+        return EntryPoint.Pattern
+    elif Path(entry_point).exists():
+        if Path(entry_point).is_dir():
+            return EntryPoint.Directory
+        else:
+            return EntryPoint.File
+    elif '.' in entry_point:
+        return EntryPoint.DottedPath
+    else:
+        raise ValueError(
+            'Could not determine the entry point type from value: '
+            f'{entry_point!r}. Expected '
+            'an existing file, directory glob-like pattern (i.e. *.py) or '
+            'dotted path (dot-separated string). Verify your input.')
+
+
+def load_entry_point(entry_point):
+    type_ = find_entry_point_type(entry_point)
+
+    if type_ == EntryPoint.Directory:
+        spec = DAGSpec.from_directory(entry_point)
+        path = Path(entry_point)
+
+    elif type_ == EntryPoint.File:
+        spec = DAGSpec(entry_point)
+        path = Path(entry_point).parent
+    else:
+        raise NotImplementedError(
+            f'loading entry point type {type_!r} is unsupported')
+
+    return spec, spec.to_dag(), path
+
+
 def _first_non_empty_line(doc):
     for line in doc.split('\n'):
         if line:
@@ -280,7 +410,7 @@ def _add_args_from_callable(parser, callable_):
     return required, defaults
 
 
-def _process_file_or_entry_point(parser):
+def _process_file_dir_or_glob(parser):
     """
     Process a file entry point file or directory), returns the initialized dag
     and parsed args
@@ -300,8 +430,12 @@ def _process_file_or_entry_point(parser):
         if args.log is not None:
             logging.basicConfig(level=args.log.upper())
 
-    if Path(args.entry_point).is_dir():
+    entry_point = EntryPoint(args.entry_point)
+
+    if entry_point.type == EntryPoint.Directory:
         dag = DAGSpec.from_directory(args.entry_point).to_dag()
+    elif entry_point.type == EntryPoint.Pattern:
+        dag = DAGSpec.from_files(args.entry_point).to_dag()
     else:
         with open(args.entry_point) as f:
             dag_dict = yaml.load(f, Loader=yaml.SafeLoader)
@@ -319,102 +453,13 @@ def _process_file_or_entry_point(parser):
     return dag, args
 
 
-def _process_entry_point(parser, entry_point, static_args):
-    """Process an entry point from the user
-
-    Parameters
-    ----------
-    parser : CustomParser
-        The cli parser object
-
-    entry_point : str
-        An entry point string, this can be either path to a file or a dotted
-        path to a function that returns a DAG
-    """
-    help_cmd = '--help' in sys.argv or '-h' in sys.argv
-
-    path = Path(entry_point)
-    entry_file_exists = path.exists()
-    entry_obj = load_dotted_path(entry_point, raise_=False)
-
-    # if the file does not exist but the value has sufix yaml/yml, show a
-    # warning because the last thing to try is to interpret it as a dotted
-    # path and that's probably not what the user wants
-    if not entry_file_exists and path.suffix in {'.yaml', '.yml'}:
-        warnings.warn('Entry point value "{}" has extension "{}", which '
-                      'suggests a spec file, but the file doesn\'t '
-                      'exist'.format(entry_point, path.suffix))
-
-    # even if the entry file is not a file nor a valid module, show the help
-    # menu, but show a warning
-    if (help_cmd and not entry_file_exists and not entry_obj):
-        warnings.warn('Failed to load entry point "{}". It is not a file '
-                      'nor a valid dotted path'.format(entry_point))
-
-        args = parser.parse_args()
-
-    # first check if the entry point is an existing file
-    elif path.exists():
-        dag, args = _process_file_or_entry_point(parser)
-    # assume it's a dotted path to a factory
-    else:
-        dag, args = parser.process_factory_dotted_path(entry_point)
-
-    return dag, args
-
-
-# TODO: the next two functions are only used to override default behavior
-# when using the jupyter extension, but they have to be integrated with the CLI
-# to provide consistent behavior. The problem is that logic implemented
-# in _process_file_or_entry_point and _process_factory_dotted_path
-# also contains some CLI specific parts that we don't require here
-def find_entry_point_type(entry_point):
-    """
-
-    Step 1: If not ENTRY_POINT is defined nor a value is passed, a default
-    value is used (pipeline.yaml for CLI, recursive lookup for Jupyter client).
-    If ENTRY_POINT is defined, this simply overrides the default value, but
-    passing a value overrides the default value. Once the value is determined.
-
-    Step 2: If value is a valid directory, DAG is loaded from such directory,
-    if it's a file, it's loaded from that file (spec), finally, it's
-    interpreted as a dotted path
-    """
-    if Path(entry_point).exists():
-        if Path(entry_point).is_dir():
-            return 'directory'
-        else:
-            return 'file'
-    else:
-        return 'dotted-path'
-
-
-def load_entry_point(entry_point):
-    type_ = find_entry_point_type(entry_point)
-
-    if type_ == 'directory':
-        spec = DAGSpec.from_directory(entry_point)
-        path = Path(entry_point)
-    elif type_ == 'file':
-        spec = DAGSpec(entry_point)
-        path = Path(entry_point).parent
-    elif type_ == 'dotted-path':
-        raise ValueError('dotted paths are currently unsupported')
-        # fn = load_dotted_path(entry_point, raise_=True)
-        # dag = fn()
-    else:
-        raise ValueError('Unknown entry point type {}'.format(type_))
-
-    return spec, spec.to_dag(), path
-
-
 def _custom_command(parser):
     """
     Parses an entry point, adding arguments by extracting them from the env.
     Returns a dag and the parsed args
     """
     entry_point = parser.parse_entry_point_value()
-    dag, args = _process_entry_point(parser, entry_point, parser.static_args)
+    dag, args = EntryPoint(entry_point).load(parser, sys.argv)
     return dag, args
 
 
