@@ -25,8 +25,6 @@ have a few rules to automatically determine language and kernel given a
 script/notebook.
 """
 import ast
-from inspect import getargspec
-import tempfile
 from pathlib import Path
 from io import StringIO
 import warnings
@@ -39,6 +37,7 @@ from ploomber.exceptions import RenderError, SourceInitializationError
 from ploomber.placeholders.Placeholder import Placeholder
 from ploomber.util import requires
 from ploomber.sources import Source
+from ploomber.sources.nb_utils import find_cell_with_tag
 from ploomber.static_analysis.extractors import extractor_class_for_language
 from ploomber.sources import docstring
 
@@ -154,25 +153,24 @@ class NotebookSource(Source):
         self._render()
 
     def _render(self):
-        import papermill as pm
-
-        tmp_in = tempfile.mktemp('.ipynb')
-        tmp_out = tempfile.mktemp('.ipynb')
         # _read_nb_str_unrendered uses hot_reload, this ensures we always get
         # the latest version
-        Path(tmp_in).write_text(self._read_nb_str_unrendered())
-        pm.execute_notebook(tmp_in,
-                            tmp_out,
-                            prepare_only=True,
-                            parameters=self._params)
+        _, nb = self._read_nb_str_unrendered()
 
-        tmp_out = Path(tmp_out)
+        # this is needed for parameterize_notebook to work
+        for cell in nb.cells:
+            if not hasattr(cell.metadata, 'tags'):
+                cell.metadata['tags'] = []
+        nb.metadata['papermill'] = dict()
 
-        self._nb_str_rendered = tmp_out.read_text()
-
-        Path(tmp_in).unlink()
-        tmp_out.unlink()
+        # NOTE: we use parameterize_notebook instead of execute_notebook
+        # with the prepare_only option because the latter adds a "papermill"
+        # section on each cell's metadata, which makes it too verbose when
+        # using NotebookRunner.develop() when the source is script (each cell
+        # will have an empty "papermill" metadata dictionary)
+        nb = parameterize_notebook(nb, self._params)
 
+        self._nb_str_rendered = nbformat.writes(nb)
         self._post_render_validation(self._params, self._nb_str_rendered)
 
     def _read_nb_str_unrendered(self):
@@ -203,7 +201,7 @@ class NotebookSource(Source):
             self._nb_str_unrendered = nbformat.writes(
                 self._nb_obj_unrendered, version=nbformat.NO_CONVERT)
 
-        return self._nb_str_unrendered
+        return self._nb_str_unrendered, self._nb_obj_unrendered
 
     def _post_init_validation(self, value):
         """
@@ -579,7 +577,7 @@ def inject_cell(model, params):
     """
     nb = nbformat.from_dict(model['content'])
 
-    # we must ensure nb has kernelspec info, otherwise papermill willf fail to
+    # we must ensure nb has kernelspec info, otherwise papermill will fail to
     # parametrize
     ext = model['name'].split('.')[-1]
     ensure_kernelspec(nb, kernelspec_name=None, ext=ext, language=None)
@@ -605,18 +603,10 @@ def inject_cell(model, params):
                'preferences. It is temporary and will be removed when you '
                'save this notebook')
 
-    # a PR was merged to include this, but it hasn't been released yet,
-    # so we check here
-    # https://github.com/nteract/papermill/pull/521
-    if 'comment' in getargspec(parameterize_notebook).args:
-        kwargs = {'comment': comment}
-    else:
-        kwargs = {}
-
     model['content'] = parameterize_notebook(nb,
                                              params,
                                              report_mode=False,
-                                             **kwargs)
+                                             comment=comment)
 
 
 # FIXME: this is used in the task itself in the .develop() feature, maybe
@@ -684,20 +674,6 @@ def is_python(nb):
     return is_python_
 
 
-def find_cell_with_tag(nb, tag):
-    """
-    Find a cell with a given tag, returns a cell, index tuple. Otherwise
-    (None, None)
-    """
-    for i, c in enumerate(nb['cells']):
-        cell_tags = c['metadata'].get('tags')
-        if cell_tags:
-            if tag in cell_tags:
-                return c, i
-
-    return None, None
-
-
 def determine_language(extension):
     """
     A function to determine programming language given file extension,
