@@ -7,6 +7,7 @@ such as a bash or a SQL script
 import shlex
 import subprocess
 import pdb
+import functools
 
 from IPython.terminal.debugger import TerminalPdb, Pdb
 
@@ -20,6 +21,19 @@ from ploomber.sources.interact import CallableInteractiveDeveloper
 from ploomber.tasks.Params import Params
 
 
+def _unserialize_params(params_original, unserializer):
+    params = params_original.to_dict()
+
+    params['upstream'] = {
+        k: unserializer(v)
+        for k, v in params['upstream'].items()
+    }
+
+    params = Params._from_dict(params, copy=False)
+
+    return params
+
+
 class PythonCallable(Task):
     """
     Run a Python callable (e.g. a function)
@@ -70,16 +84,10 @@ class PythonCallable(Task):
         return PythonCallableSource(source, **kwargs)
 
     def run(self):
-        params = self.params.to_dict()
-
-        # unserialize upstream dependencies if needed
-        if 'upstream' in params and self._unserializer:
-            params['upstream'] = {
-                k: self._unserializer(v)
-                for k, v in params['upstream'].items()
-            }
-
-        params = Params._from_dict(params, copy=False)
+        if 'upstream' in self.params and self._unserializer:
+            params = _unserialize_params(self.params, self._unserializer)
+        else:
+            params = self.params.to_dict()
 
         # do not pass product if serializer is set, we'll use the returned
         # value in such case
@@ -135,22 +143,20 @@ class PythonCallable(Task):
                 'not been '
                 'rendered, call DAG.render() first'.format(self.name))
 
-        # TODO: Params should implement an option to call to_json_serializable
-        # on product to avoid repetition I'm using this same code in notebook
-        # runner. Also raise error if any of the params is not
-        # json serializable
-        # TODO: resolve to absolute to make relative paths work
-        params = self.params.to_json_serializable()
-        params['product'] = params['product'].to_json_serializable()
-
-        with CallableInteractiveDeveloper(self.source.primitive,
-                                          params) as tmp:
+        with self._interactive_developer() as tmp:
             try:
                 subprocess.run(['jupyter', app, tmp] + shlex.split(args or ''),
                                check=True)
             except KeyboardInterrupt:
                 print(f'Jupyter {app} application closed...')
 
+    def _interactive_developer(self):
+        """
+        Creates a CallableInteractiveDeveloper instance
+        """
+        # TODO: resolve to absolute to make relative paths work
+        return CallableInteractiveDeveloper(self.source.primitive, self.params)
+
     def debug(self, kind='ipdb'):
         """
         Run callable in debug mode.
@@ -180,6 +186,15 @@ class PythonCallable(Task):
                                  'not been '
                                  'rendered, call DAG.render() first'.format(
                                      self.name))
+
+        if 'upstream' in self.params and self._unserializer:
+            params = _unserialize_params(self.params, self._unserializer)
+        else:
+            params = self.params.to_dict()
+
+        if self._serializer:
+            params.pop('product')
+
         if kind == 'ipdb':
             try:
                 # this seems to only work in a Terminal
@@ -188,9 +203,34 @@ class PythonCallable(Task):
                 # this works in a Jupyter notebook
                 ipdb = Pdb()
 
-            ipdb.runcall(self.source.primitive, **self.params)
+            ipdb.runcall(self.source.primitive, **params)
         elif kind == 'pdb':
-            pdb.runcall(self.source.primitive, **self.params)
+            pdb.runcall(self.source.primitive, **params)
+
+    def load(self):
+        """
+        Loads the product, only works if the task is initialized with an
+        unzerializer
+        """
+        if self._unserializer is None:
+            raise ValueError('Cannot load product, task was not initialized '
+                             'with an unserializer function')
+
+        return self._unserializer(str(self.product))
+
+
+def task_factory(_func=None, **factory_kwargs):
+    """Syntactic sugar for building PythonCallable tasks
+    """
+    def decorator(func):
+        @functools.wraps(func)
+        def wrapper(**wrapper_kwargs):
+            kwargs = {**factory_kwargs, **wrapper_kwargs}
+            return PythonCallable(func, **kwargs)
+
+        return wrapper
+
+    return decorator if _func is None else decorator(_func)
 
 
 class ShellScript(Task):
