@@ -1,9 +1,13 @@
 from ploomber.util.util import (safe_remove, image_bytes2html, isiterable,
                                 requires, chdir_code)
-from ploomber.util import markup
 from ploomber.util.param_grid import Interval, ParamGrid
 
 __all__ = [
-    'safe_remove', 'image_bytes2html', 'Interval', 'ParamGrid', 'isiterable',
-    'requires', 'markup', 'chdir_code'
+    'safe_remove',
+    'image_bytes2html',
+    'Interval',
+    'ParamGrid',
+    'isiterable',
+    'requires',
+    'chdir_code',
 ]
